==> geant4_vmc.3.6.tar.gz: geant4_vmc-3-6/g4root/test/OpNovice/OpNovice.cc <==
//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//
//
//
//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
//
// Description: Test of Continuous Process G4Cerenkov
//              and RestDiscrete Process G4Scintillation
//              -- Generation Cerenkov Photons --
//              -- Generation Scintillation Photons --
//              -- Transport of optical Photons --
// Version:     5.0
// Created:     1996-04-30
// Author:      Juliet Armstrong
// mail:        gum@triumf.ca
//     
//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......

/// \file OpNoviceGeom.cc
/// \brief Geant4 OpNovice example adapted to G4Root test
///
/// \author A. Gheata; CERN

#ifdef G4MULTITHREADED
#include "G4MTRunManager.hh"
#else
#include "G4RunManager.hh"
#endif

#include "G4UImanager.hh"

#include "OpNovicePhysicsList.hh"
#include "OpNoviceDetectorConstruction.hh"
// Added for G4Root
#include "OpNovicePostDetConstruction.hh"

#include "OpNoviceActionInitialization.hh"

// Added for G4Root - start
#include "TGeoManager.h"
#include "TG4RootDetectorConstruction.h"
#include "TG4RootNavMgr.h"
// Added for G4Root - end

#ifdef G4VIS_USE
#include "G4VisExecutive.hh"
#endif

#ifdef G4UI_USE
#include "G4UIExecutive.hh"
#endif

//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
namespace {
  void PrintUsage() {
    G4cerr << " Usage: " << G4endl;
    G4cerr << " OpNovice [-m macro ] [-u UIsession] [-t nThreads] [-r seed] "
           // Added for G4Root
           << " [-g useG4Root]"
           << G4endl;
    G4cerr << "   note: -t option is available only for multi-threaded mode."
           << G4endl;
  }
}

//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......

int main(int argc,char** argv)
{
  // Evaluate arguments
  //
  if ( argc > 9 ) {
    PrintUsage();
    return 1;
  }

  G4String macro;
  G4String session;
  G4int nThreads = 0;

  // Added for G4Root - start
  G4bool useG4Root = false;
  TGeoManager *geom = 0;
  TG4RootNavMgr *mgr = 0;
  // Added for G4Root - end
  
  G4long myseed = 345354;
  for ( G4int i=1; i<argc; i=i+2 ) {
     if      ( G4String(argv[i]) == "-m" ) macro   = argv[i+1];
     else if ( G4String(argv[i]) == "-u" ) session = argv[i+1];
     // Added for G4Root
     else if ( G4String(argv[i]) == "-g" ) useG4Root = true;
     else if ( G4String(argv[i]) == "-r" ) myseed  = atoi(argv[i+1]);
#ifdef G4MULTITHREADED
     else if ( G4String(argv[i]) == "-t" ) {
                    nThreads = G4UIcommand::ConvertToInt(argv[i+1]);
    }
#endif
    else {
      PrintUsage();
      return 1;
    }
  }

  // Choose the Random engine
  //
  G4Random::setTheEngine(new CLHEP::RanecuEngine);

  // Construct the default run manager
  //

  // Added for G4Root - start
  if ( useG4Root ) {
     G4cout << "Using TGeo interface ..." << G4endl;
     geom = TGeoManager::Import("OpNoviceGeom.root");
     mgr = TG4RootNavMgr::GetInstance(geom);
  } else {
     G4cout << "Using G4 native ..." << G4endl;  
  }
  // Added for G4Root - end

#ifdef G4MULTITHREADED
  G4MTRunManager * runManager = new G4MTRunManager;
  if ( nThreads > 0 ) runManager->SetNumberOfThreads(nThreads);
#else
  G4RunManager * runManager = new G4RunManager;
#endif

  // Added for G4Root - start
  if ( useG4Root ) {
     mgr->Initialize(OpNovicePostDetConstruction::GetInstance(), nThreads);
     mgr->ConnectToG4();
  }   
  // Added for G4Root - end

  // Seed the random number generator manually
  G4Random::setTheSeed(myseed);

  // Set mandatory initialization classes
  //
  // Detector construction
  // Added for G4Root - start
  if ( ! useG4Root ) {
    runManager->SetUserInitialization(new OpNoviceDetectorConstruction());
  }  
  // Added for G4Root - end

  // Physics list
  runManager-> SetUserInitialization(new OpNovicePhysicsList());
  // User action initialization
  runManager->SetUserInitialization(new OpNoviceActionInitialization(useG4Root));

  // Initialize G4 kernel
  //
  runManager->Initialize();

#ifdef G4VIS_USE
  // Initialize visualization
  //
  G4VisManager* visManager = new G4VisExecutive;
  // G4VisExecutive can take a verbosity argument - see /vis/verbose guidance.
  // G4VisManager* visManager = new G4VisExecutive("Quiet");
  visManager->Initialize();
#endif

  // Get the pointer to the User Interface manager
  //
  G4UImanager* UImanager = G4UImanager::GetUIpointer(); 
   
  if ( macro.size() ) {
     // Batch mode
     G4String command = "/control/execute ";
     UImanager->ApplyCommand(command+macro);
  }
  else // Define UI session for interactive mode
  {
#ifdef G4UI_USE
     G4UIExecutive * ui = new G4UIExecutive(argc,argv,session);
#ifdef G4VIS_USE
     UImanager->ApplyCommand("/control/execute vis.mac");
#else
     UImanager->ApplyCommand("/control/execute OpNovice.in");
#endif
     if (ui->IsGUI())
        UImanager->ApplyCommand("/control/execute gui.mac");
     ui->SessionStart();
     delete ui;
#endif
  }

  // Job termination
  // Free the store: user actions, physics_list and detector_description are
  //                 owned and deleted by the run manager, so they should not
  //                 be deleted in the main() program !

#ifdef G4VIS_USE
  delete visManager;
#endif
  delete runManager;

  return 0;
}

//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......

==> geant4_vmc-6.2.tar.gz: geant4_vmc-6-2/g4root/test/OpNovice/OpNovice.cc <==
//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//
/// \file OpNovice/OpNovice.cc
/// \brief Main program of the OpNovice example
///
/// Geant4 OpNovice example adapted to G4Root test
///
/// \author A. Gheata; CERN

//
//
//
//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
//
// Description: Test of Continuous Process G4Cerenkov
//              and RestDiscrete Process G4Scintillation
//              -- Generation Cerenkov Photons --
//              -- Generation Scintillation Photons --
//              -- Transport of optical Photons --
// Version:     5.0
// Created:     1996-04-30
// Author:      Juliet Armstrong
//
//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......

#include "OpNoviceDetectorConstruction.hh"
#ifdef GEANT4_USE_GDML
#  include "OpNoviceGDMLDetectorConstruction.hh"
#endif
#include "OpNoviceActionInitialization.hh"
// Added for G4Root
#include "OpNovicePostDetConstruction.hh"

// Added for G4Root - start
#include "TGeoManager.h"
#include "TG4RootDetectorConstruction.h"
#include "TG4RootNavMgr.h"
// Added for G4Root - end

#include "FTFP_BERT.hh"
#include "G4EmStandardPhysics_option4.hh"
#include "G4OpticalPhysics.hh"
#include "G4RunManagerFactory.hh"
#include "G4Types.hh"
#include "G4UIExecutive.hh"
#include "G4UImanager.hh"
#include "G4VisExecutive.hh"


//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
namespace
{
  void PrintUsage()
  {
    G4cerr << " Usage: " << G4endl;
#ifdef GEANT4_USE_GDML
    G4cerr << " OpNovice [-g gdmlfile] [-m macro ] [-u UIsession] [-t "
              "nThreads] [-r seed] "
           // Added for G4Root
           << " [-gr useG4Root]"
           << G4endl;
#else
    G4cerr << " OpNovice  [-m macro ] [-u UIsession] [-t nThreads] [-r seed] "
           // Added for G4Root
           << " [-gr useG4Root]"
           << G4endl;
#endif
    G4cerr << "   note: -t option is available only for multi-threaded mode."
           << G4endl;
  }
}  // namespace

//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......

int main(int argc, char** argv)
{
  // Evaluate arguments
  //
  if(argc > 9)
  {
    PrintUsage();
    return 1;
  }
  G4String gdmlfile = "";
  G4String macro;
  G4String session;
  G4int nThreads = 0;
  // Added for G4Root - start
  G4bool useG4Root = false;
  TGeoManager *geom = 0;
  TG4RootNavMgr *mgr = 0;
  // Added for G4Root - end


  G4long myseed = 345354;
  for(G4int i = 1; i < argc; i = i + 2)
  {
    if(G4String(argv[i]) == "-g")
      gdmlfile = argv[i + 1];
    else if(G4String(argv[i]) == "-m")
      macro = argv[i + 1];
    else if(G4String(argv[i]) == "-u")
      session = argv[i + 1];
    else if(G4String(argv[i]) == "-r")
      myseed = atoi(argv[i + 1]);
    // Added for G4Root
    else if ( G4String(argv[i]) == "-gr" ) 
      useG4Root = true;
#ifdef G4MULTITHREADED
    else if(G4String(argv[i]) == "-t")
    {
      nThreads = G4UIcommand::ConvertToInt(argv[i + 1]);
    }
#endif
    else
    {
      PrintUsage();
      return 1;
    }
  }

  // Instantiate G4UIExecutive if interactive mode
  G4UIExecutive* ui = nullptr;
  if(macro.size() == 0)
  {
    ui = new G4UIExecutive(argc, argv);
  }

  // Added for G4Root - start
  if ( useG4Root ) {
     G4cout << "Using TGeo interface ..." << G4endl;
     geom = TGeoManager::Import("OpNoviceGeom.root");
     mgr = TG4RootNavMgr::GetInstance(geom);
  } else {
     G4cout << "Using G4 native ..." << G4endl;
  }
  // Added for G4Root - end

  // Construct the default run manager
  auto runManager = G4RunManagerFactory::CreateRunManager();
#ifdef G4MULTITHREADED
  if(nThreads > 0)
    runManager->SetNumberOfThreads(nThreads);
#endif

  // Added for G4Root - start
  if ( useG4Root ) {
     mgr->Initialize(OpNovicePostDetConstruction::GetInstance(), nThreads);
     mgr->ConnectToG4();
  }
  // Added for G4Root - end

  // Seed the random number generator manually
  G4Random::setTheSeed(myseed);

  // Set mandatory initialization classes
  //
  // Detector construction
  if(gdmlfile != "")
  {
#ifdef GEANT4_USE_GDML
    runManager->SetUserInitialization(
      new OpNoviceGDMLDetectorConstruction(gdmlfile));
#else
    G4cout << "Error! Input gdml file specified, but Geant4 wasn't" << G4endl
           << "built with gdml support." << G4endl;
    return 1;
#endif
  }
  else
  {
    // Added for G4Root - start
    if ( ! useG4Root ) {
      runManager->SetUserInitialization(new OpNoviceDetectorConstruction());
    }
    // Added for G4Root - end
  }
  // Physics list
  G4VModularPhysicsList* physicsList = new FTFP_BERT;
  physicsList->ReplacePhysics(new G4EmStandardPhysics_option4());
  G4OpticalPhysics* opticalPhysics = new G4OpticalPhysics();
  physicsList->RegisterPhysics(opticalPhysics);
  runManager->SetUserInitialization(physicsList);

  runManager->SetUserInitialization(new OpNoviceActionInitialization(useG4Root));

  G4VisManager* visManager = new G4VisExecutive("Quiet");
  visManager->Initialize();

  G4UImanager* UImanager = G4UImanager::GetUIpointer();

  if(macro.size())
  {
    G4String command = "/control/execute ";
    UImanager->ApplyCommand(command + macro);
  }
  else  // Define UI session for interactive mode
  {
    UImanager->ApplyCommand("/control/execute vis.mac");
    if(ui->IsGUI())
      UImanager->ApplyCommand("/control/execute gui.mac");
    ui->SessionStart();
    delete ui;
  }

  delete visManager;
  delete runManager;

  return 0;
}

//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
